@@ -99,7 +99,7 @@ static int _generate_ident( char * id_str, size_t length )
 #endif
   strftime(time_str, sizeof(time_str), "%Y.%m.%d.%H.%M.%S", &tm_buf);
   
-  result = snprintf(id_str, length, "%s:%s:%s:%u:%u", 
+  result = snprintf(id_str, length, "%s:%s:%s:%u:%d", 
                     user_str, 
                     host_str, 
                     time_str, 
@@ -281,7 +281,6 @@ int micreate_volume_image(mihandle_t volume)
 {
   char dimorder[MI2_CHAR_LENGTH];
   int i;
-  int dimorder_len=0;
   hid_t dataspace_id;
   hid_t dset_id;
   hsize_t hdf_size[MI2_MAX_VAR_DIMS];
