@@ -25,8 +25,6 @@ double rint(double v); /*hack: defined in m2util.c*/
 #define VALID_MIN (0.0)
 #define REAL_MAX (1.0)
 #define REAL_MIN (-1.0)
-#define NORM_MAX (1.0)
-#define NORM_MIN (-1.0)
 
 static int
 create_and_test_image(const char *name, 
@@ -39,9 +37,7 @@ create_and_test_image(const char *name,
   misize_t start[NDIMS];
   misize_t count[NDIMS];
   double stmp2[CX][CY][CZ];
-  double dtemp;
   int i,j,k;
-  char *dimnames[] = {"zspace", "xspace", "yspace"};
   int error_cnt = 0;
 
   result = micreate_dimension("xspace", MI_DIMCLASS_SPATIAL, 
@@ -138,9 +134,9 @@ int
 main(void){
   mihandle_t hvol;
   midimhandle_t hdims[NDIMS];
-  double outval;
+  double outval = 0.0;
   
-  double error_count = create_and_test_image("test-dbl.mnc", &hvol, hdims, outval);
+  int error_count = create_and_test_image("test-dbl.mnc", &hvol, hdims, outval);
 
   // clean up memory
   if(miclose_volume ( hvol )>0) error_count++;
